Getting Started
===============

Installing bt
-------------

The easiest way to install ``bt`` is from the `Python Package Index <https://pypi.python.org/pypi/bt/>`_
using ``pip`` or ``easy_insatll``:

.. code-block:: bash

    $ pip install bt 

Since bt has many dependencies, we strongly recommend installing the `Anaconda Scientific Python
Distribution <https://store.continuum.io/cshop/anaconda/>`_, especially on Windows. This distribution 
comes with many of the required packages pre-installed, including pip. Once Anaconda is installed, the above 
command should complete the installation. 

bt should be compatible with Python 2.7. 

Recommended Setup
-----------------

We believe the best environment to develop with bt is the `IPython Notebook
<http://ipython.org/notebook.html>`__. From their homepage, the IPython Notebook
is:

    "[...] a web-based interactive computational environment
    where you can combine code execution, text, mathematics, plots and rich
    media into a single document [...]"

This environment allows you to plot your charts in-line and also allows you to
easily add surrounding text with Markdown. You can easily create Notebooks that
you can share with colleagues and you can also save them as PDFs. If you are not
yet convinced, head over to their website.
